==> hermes-6.1.1.3.rec2.tar.gz: hermes-6.1.1.3.rec2/app/serializers/hermes/housing_request_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class HousingRequestSerializer < Hermes::ApplicationSerializer
    type 'housing_requests'

    attribute :backoffice_status
    attribute :is_active
    attribute :als_id
    attribute :request_status
    attribute :attributed_housing_district
    attribute :attributed_housing_district_postal_code
    attribute :old_request_status
    attribute :request_status_updated_at
    attribute :old_entity_status
    attribute :entity_status_updated_at
    attribute :entity_status
    attribute :dalo
    attribute :asked_mobility
    attribute :valid_mobility
    attribute :decider
    attribute :mobility
    attribute :seeked_types
    attribute :entity_help_required
    attribute :contract_type
    attribute :registration_number
    attribute :applicant_ids
    attribute :entity_validated
    attribute :entity_refused
    attribute :priority_points_indexes
    attribute :has_priority
    attribute :nud
    attribute :nb_of_requests_made
    attribute :reference_tax_revenues
    attribute :seeked_districts
    attribute :category_type
    attribute :single_parent
    attribute :id_counter
    attribute :id_unique
    attribute :id_unique_associate
    attribute :internal_ref
    attribute :forcing_duplicate
    attribute :electronical_renewal
    attribute :ec_law_ressources
    attribute :is_long_delay_anormal
    attribute :date_calculator_indicator
    attribute :with_car_park
    attribute :widen_request
    attribute :housing_type_list
    attribute :expulsion_judgement_date
    attribute :other_reason
    attribute :work_contract_type
    attribute :seeked_district_postal_codes
    attribute :seeked_departments
    attribute :seeked_localisation_list
    attribute :dependents
    attribute :monthly_revenues
    attribute :dependents_monthly_incomes
    attribute :dependents_monthly_charges
    attribute :typology_range
    attribute :entity_validated
    attribute :coapplicants
    attribute :lessor_name
    attribute :lessor_siren
    attribute :social_housing_entry_date
    attribute :social_housing_name
    attribute :test_created_at
    attribute :sne_number
    attribute :employee_id
    attribute :employee_start_date
    attribute :entity_access_level
    attribute :employee_unit
    attribute :tab_state
    attribute :motivations
    attribute :seeking_first_floor
    attribute :seeking_elevator
    attribute :seeked_max_rent
    attribute :seeked_epci_first_quartils
    attribute :seeked_quartil_belongings
    attribute :sne_created_at
    attribute :next_renewal_date_set_by_sne
    attribute :next_sne_renewal_date
    attribute :last_sne_renewal_date
    attribute :soon_need_to_be_renewed
    attribute :need_to_be_renewed
    attribute :precisions
    attribute :has_multiple_attributions_under_conditions
    attribute :seeked_housing_categories
    attribute :min_surface
    attribute :main_applicant_id
    attribute :main_applicant
    attribute :requester_firstname
    attribute :requester_lastname
    attribute :requester_fullname
    attribute :requester_email
    attribute :requester_birth_date
    attribute :coapplicant_ids
    attribute :coapplicants
    attribute :applications_nb
    attribute :last_application_date
    attribute :housing_application_ids
    attribute :active_application_id
    attribute :active_application_housing_offer_id
    attribute :target_offer_reserving_business
    attribute :form_status
    attribute :entity_id
    attribute :old_entity_id
    attribute :documents_required
    attribute :documents_uploaded
    attribute :unborn_children
    attribute :is_house_owner
    attribute :workplace_insee_code
    attribute :unique_numbers
    attribute :providers
    attribute :unique_numbers_complete
    attribute :is_untensed_area
    attribute :housing_channel_chosen_keys
    attribute :housing_channel_pending_keys
    attribute :housing_channel_keys
    attribute :is_sne_update_available
    attribute :last_search_on_sne
    attribute :housing_offer_ids
    attribute :last_search_on_sne
    attribute :viewed_by_colaborator_offre_logement
    if HERMES_CONFIG['DEBUG_ERRORS'] == false
      attribute :last_xml_validation_report
    end
    attribute :last_send_has_error
    attribute :last_entity_code
    attribute :consent_level
    attribute :cdii
    attribute :last_update_user_id
    attribute :last_update_user_last_name
    attribute :last_update_user_first_name


    attribute :dependents, key_transformation: :unaltered
    attribute :disability_details, key_transformation: :unaltered
    attribute :profession_details, key_transformation: :unaltered
    attribute :actual_housing_details, key_transformation: :unaltered
    attribute :postal_details, key_transformation: :unaltered
    attribute :owned_housing_details, key_transformation: :unaltered
    attribute :applicant_verified
    
    attribute :eligible_offers_count, if: :eligible_offers_count?
    attribute :eligible_count, if: :eligible_count?

    attribute :have_monthly_income
    attribute :disabled_person_number
    attribute :owner_info_needed
    attribute :cerfa_version

    attribute :profile_score
    attribute :bonus_points
    attribute :score_details

    attribute :hash_xml
    attribute :last_successful_xml_sent_date
    attribute :striked_off_motives
    attribute :is_striked_off

    attribute :applicant_used_for_siret_firstname
    attribute :applicant_used_for_siret_lastname
    attribute :applicant_used_for_siret_fullname
    attribute :applicant_used_for_siret_email
    attribute :applicant_used_for_siret_birth_date
    
    attribute :cotations
    attribute :supplement_status
    attribute :supplement_can_apply


    attribute :form_sne_validation_errors
    attribute :form_front_validation_errors

    attribute :applicant_used_for_siret

    attribute :business_cotation

    attribute :applicants_attached_codes
    
    attribute :updated_orientation_at
    attribute :bordering_insee_codes
    attribute :eligibility_query_base
    attribute :eligibility_query_department
    attribute :eligibility_query_seeked
    attribute :eligibility_query_bordering
    attribute :eligibility_query_seeked_bordering
    attribute :eligibility_query_other_from_department

    belongs_to :housing_request_folder, serializer: HousingRequestFolderSerializer do
      object.housing_request_folder
    end

    def added_to_object_cache_key
      eligible_offers_count?|| eligible_count? ? (DateTime.current.to_i / 10).to_s  : "" 
    end 

    def housing_offer_ids
      object.housing_offer_ids&.map(&:to_s) || []
    end
    
    def unique_numbers
      object.unique_numbers
    end
    
    def providers
      res = []
      object.nuds&.each do |nud|
        res.push(nud.provider)
      end
      res
    end
    
    def unique_numbers_complete
      res = []
      object.nuds&.each do |nud|
        res.push({id: nud.id.to_s, unique_number: nud.unique_number, provider: nud.provider} )
      end
      res
    end
    
    def form_status
      object.form_status
    end
    
    def eligible_offers_count?
      @instance_options[:eligible_offers_count] == true
    end
    
    def eligible_count?
      @instance_options[:eligible_count] == true
    end
    
    def eligible_offers_count
      offers = Hermes::HousingOffer.where(object.all_eligibility_query)
      offers = offers.where(:reserving_siren.in => @instance_options[:reserving_sirens] ) if @instance_options[:reserving_sirens]
      offers.count
    end
    
    def main_applicant_id
      object.main_applicant_id&.to_s
    end
    
    def main_applicant
      return nil unless object.main_applicant
      
      Hermes::ApplicantSerializer.new(
        object.main_applicant,
        scope: scope,
        root: false
      )
    end
    
    def entity_id
      object.entity_id&.to_s
    end
    
    def coapplicant_ids
      object.applicant_ids&.map(&:to_s)
    end
    
    def coapplicants
      object.coapplicants
    end
    
    def housing_application_ids
      object.housing_applications&.map {|a| a.id.to_s} || []
    end

    def eligible_count
      eligible_count = {}
      Hermes::HousingRequest.eligibility_types.each do |type|
        eligible_count["#{type}_count"] =  object.eligibles_offers(type).count
      end 
      eligible_count["total_count"] = eligible_count["seeked_bordering_count"] + eligible_count["other_from_department_count"]
      eligible_count
    end 
  end
end

==> hermes-6.2.0.4.rec2.tar.gz: hermes-6.2.0.4.rec2/app/serializers/hermes/housing_request_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class HousingRequestSerializer < Hermes::ApplicationSerializer
    type 'housing_requests'

    attribute :backoffice_status
    attribute :is_active
    attribute :als_id
    attribute :request_status
    attribute :attributed_housing_district
    attribute :attributed_housing_district_postal_code
    attribute :old_request_status
    attribute :request_status_updated_at
    attribute :old_entity_status
    attribute :entity_status_updated_at
    attribute :entity_status
    attribute :dalo
    attribute :asked_mobility
    attribute :valid_mobility
    attribute :decider
    attribute :mobility
    attribute :seeked_types
    attribute :entity_help_required
    attribute :contract_type
    attribute :registration_number
    attribute :applicant_ids
    attribute :entity_validated
    attribute :entity_refused
    attribute :priority_points_indexes
    attribute :has_priority
    attribute :nud
    attribute :nb_of_requests_made
    attribute :reference_tax_revenues
    attribute :seeked_districts
    attribute :category_type
    attribute :single_parent
    attribute :id_counter
    attribute :id_unique
    attribute :id_unique_associate
    attribute :internal_ref
    attribute :forcing_duplicate
    attribute :electronical_renewal
    attribute :ec_law_ressources
    attribute :is_long_delay_anormal
    attribute :date_calculator_indicator
    attribute :with_car_park
    attribute :widen_request
    attribute :housing_type_list
    attribute :expulsion_judgement_date
    attribute :other_reason
    attribute :work_contract_type
    attribute :seeked_district_postal_codes
    attribute :seeked_departments
    attribute :seeked_localisation_list
    attribute :dependents
    attribute :monthly_revenues
    attribute :dependents_monthly_incomes
    attribute :dependents_monthly_charges
    attribute :typology_range
    attribute :entity_validated
    attribute :coapplicants
    attribute :lessor_name
    attribute :lessor_siren
    attribute :social_housing_entry_date
    attribute :social_housing_name
    attribute :test_created_at
    attribute :sne_number
    attribute :employee_id
    attribute :employee_start_date
    attribute :entity_access_level
    attribute :employee_unit
    attribute :tab_state
    attribute :motivations
    attribute :seeking_first_floor
    attribute :seeking_elevator
    attribute :seeked_max_rent
    attribute :seeked_epci_first_quartils
    attribute :seeked_quartil_belongings
    attribute :sne_created_at
    attribute :next_renewal_date_set_by_sne
    attribute :next_sne_renewal_date
    attribute :last_sne_renewal_date
    attribute :soon_need_to_be_renewed
    attribute :need_to_be_renewed
    attribute :precisions
    attribute :has_multiple_attributions_under_conditions
    attribute :seeked_housing_categories
    attribute :min_surface
    attribute :main_applicant_id
    attribute :main_applicant
    attribute :requester_firstname
    attribute :requester_lastname
    attribute :requester_fullname
    attribute :requester_email
    attribute :requester_birth_date
    attribute :coapplicant_ids
    attribute :coapplicants
    attribute :applications_nb
    attribute :last_application_date
    attribute :housing_application_ids
    attribute :active_application_id
    attribute :active_application_housing_offer_id
    attribute :target_offer_reserving_business
    attribute :form_status
    attribute :entity_id
    attribute :old_entity_id
    attribute :documents_required
    attribute :documents_uploaded
    attribute :unborn_children
    attribute :is_house_owner
    attribute :workplace_insee_code
    attribute :unique_numbers
    attribute :providers
    attribute :unique_numbers_complete
    attribute :is_untensed_area
    attribute :housing_channel_chosen_keys
    attribute :housing_channel_pending_keys
    attribute :housing_channel_keys
    attribute :is_sne_update_available
    attribute :last_search_on_sne
    attribute :housing_offer_ids
    attribute :last_search_on_sne
    attribute :viewed_by_colaborator_offre_logement
    if HERMES_CONFIG['DEBUG_ERRORS'] == false
      attribute :last_xml_validation_report
    end
    attribute :last_send_has_error
    attribute :last_entity_code
    attribute :consent_level
    attribute :cdii
    attribute :last_update_user_id
    attribute :last_update_user_last_name
    attribute :last_update_user_first_name


    attribute :dependents, key_transformation: :unaltered
    attribute :disability_details, key_transformation: :unaltered
    attribute :profession_details, key_transformation: :unaltered
    attribute :actual_housing_details, key_transformation: :unaltered
    attribute :postal_details, key_transformation: :unaltered
    attribute :owned_housing_details, key_transformation: :unaltered
    attribute :applicant_verified
    
    attribute :eligible_offers_count, if: :eligible_offers_count?
    attribute :eligible_count, if: :eligible_count?

    attribute :have_monthly_income
    attribute :disabled_person_number
    attribute :owner_info_needed
    attribute :cerfa_version

    attribute :profile_score
    attribute :bonus_points
    attribute :score_details

    attribute :hash_xml
    attribute :last_successful_xml_sent_date
    attribute :striked_off_motives
    attribute :is_striked_off

    attribute :applicant_used_for_siret_firstname
    attribute :applicant_used_for_siret_lastname
    attribute :applicant_used_for_siret_fullname
    attribute :applicant_used_for_siret_email
    attribute :applicant_used_for_siret_birth_date
    
    attribute :cotations
    attribute :supplement_status
    attribute :supplement_can_apply


    attribute :form_sne_validation_errors
    attribute :form_front_validation_errors

    attribute :applicant_used_for_siret

    attribute :business_cotation

    attribute :bordering_insee_codes
    attribute :eligibility_query_base
    attribute :eligibility_query_department
    attribute :eligibility_query_seeked
    attribute :eligibility_query_bordering
    attribute :eligibility_query_seeked_bordering
    attribute :eligibility_query_other_from_department
    attribute :all_eligibility_codes
    
    attribute :applicants_attached_codes
    
    attribute :updated_orientation_at
    attribute :user_email

    belongs_to :housing_request_folder, serializer: HousingRequestFolderSerializer do
      object.housing_request_folder
    end

    def added_to_object_cache_key
      eligible_offers_count?|| eligible_count? ? (DateTime.current.to_i / 10).to_s  : "" 
    end 

    def user_email
      object.user&.email
    end 

    def housing_offer_ids
      object.housing_offer_ids&.map(&:to_s) || []
    end
    
    def unique_numbers
      object.unique_numbers
    end
    
    def providers
      res = []
      object.nuds&.each do |nud|
        res.push(nud.provider)
      end
      res
    end
    
    def unique_numbers_complete
      res = []
      object.nuds&.each do |nud|
        res.push({id: nud.id.to_s, unique_number: nud.unique_number, provider: nud.provider} )
      end
      res
    end
    
    def form_status
      object.form_status
    end
    
    def eligible_offers_count?
      @instance_options[:eligible_offers_count] == true
    end
    
    def eligible_count?
      @instance_options[:eligible_count] == true
    end
    
    def eligible_offers_count
      return 0 if object.eligibility_query_base.nil?
      offers = Hermes::HousingOffer.where(object.all_eligibility_query)
      offers = offers.where(:reserving_siren.in => @instance_options[:reserving_sirens] ) if @instance_options[:reserving_sirens]
      offers.count(hint: object.eligibility_find_hint)
    end
    
    def main_applicant_id
      object.main_applicant_id&.to_s
    end
    
    def main_applicant
      return nil unless object.main_applicant
      
      Hermes::ApplicantSerializer.new(
        object.main_applicant,
        scope: scope,
        root: false
      )
    end
    
    def entity_id
      object.entity_id&.to_s
    end
    
    def coapplicant_ids
      object.applicant_ids&.map(&:to_s)
    end
    
    def coapplicants
      object.coapplicants
    end

    def eligible_count
      eligible_count = {}
      Hermes::HousingRequest.eligibility_types.each do |type|
        eligible_count["#{type}_count"] =  object.eligibles_offers(type).count(hint: object.eligibility_find_hint)
      end 
      eligible_count["total_count"] = eligible_count["seeked_bordering_count"] + eligible_count["other_from_department_count"]
      eligible_count
    end 
  end
end
